==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.md <==
# AmazonCloudWatchEventTimeBased


```text
aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')
```



| Illustration | AmazonCloudWatchEventTimeBased | AmazonCloudWatchEventTimeBasedCard | AmazonCloudWatchEventTimeBasedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.png) | ![illustration for AmazonCloudWatchEventTimeBased](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.Local.png) | ![illustration for AmazonCloudWatchEventTimeBasedCard](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBasedCard.Local.png) | ![illustration for AmazonCloudWatchEventTimeBasedGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBasedGroup.Local.png) |




## AmazonCloudWatchEventTimeBased

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBased
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBased('AmazonCloudWatchEventTimeBased', 'Amazon Cloud Watch Event Time Based', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBased
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBased('AmazonCloudWatchEventTimeBased', 'Amazon Cloud Watch Event Time Based', 'an optional tech label')
@enduml
```

## AmazonCloudWatchEventTimeBasedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedCard('AmazonCloudWatchEventTimeBasedCard', 'Amazon Cloud Watch Event Time Based Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedCard('AmazonCloudWatchEventTimeBasedCard', 'Amazon Cloud Watch Event Time Based Card', 'an optional description')
@enduml
```

## AmazonCloudWatchEventTimeBasedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedGroup('AmazonCloudWatchEventTimeBasedGroup', 'Amazon Cloud Watch Event Time Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedGroup('AmazonCloudWatchEventTimeBasedGroup', 'Amazon Cloud Watch Event Time Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.md <==
# AmazonCloudWatchEventTimeBased


```text
aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')
```



| Illustration | AmazonCloudWatchEventTimeBased | AmazonCloudWatchEventTimeBasedCard | AmazonCloudWatchEventTimeBasedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.png) | ![illustration for AmazonCloudWatchEventTimeBased](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.Local.png) | ![illustration for AmazonCloudWatchEventTimeBasedCard](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBasedCard.Local.png) | ![illustration for AmazonCloudWatchEventTimeBasedGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBasedGroup.Local.png) |




## AmazonCloudWatchEventTimeBased

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBased
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBased('AmazonCloudWatchEventTimeBased', 'Amazon Cloud Watch Event Time Based', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBased
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBased('AmazonCloudWatchEventTimeBased', 'Amazon Cloud Watch Event Time Based', 'an optional tech label')
@enduml
```

## AmazonCloudWatchEventTimeBasedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedCard('AmazonCloudWatchEventTimeBasedCard', 'Amazon Cloud Watch Event Time Based Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedCard('AmazonCloudWatchEventTimeBasedCard', 'Amazon Cloud Watch Event Time Based Card', 'an optional description')
@enduml
```

## AmazonCloudWatchEventTimeBasedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedGroup('AmazonCloudWatchEventTimeBasedGroup', 'Amazon Cloud Watch Event Time Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedGroup('AmazonCloudWatchEventTimeBasedGroup', 'Amazon Cloud Watch Event Time Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
